Learn R Programming

clinspacy (version 1.0.2)

dataset_cui2vec_definitions: Cui2vec concept definitions

Description

This dataset contains definitions for the Unified Medical Language System (UMLS) Concept Unique Identifiers (CUIs). These come from Andrew Beam's cui2vec R package.

Usage

dataset_cui2vec_definitions()

Arguments

Value

Returns the cui2vec UMLS definitions as a data frame.

Format

A data frame with 3053795 rows and 3 variables:

cui

A Unified Medical Language System (UMLS) Concept Unique Identifier (CUI)

semantic_type

Semantic type of the CUI

definition

Definition of the CUI

Details

License

This data is made available under a MIT license. The data is copyrighted in 2019 by Benjamin Kompa, Andrew Beam, and Allen Schmaltz. The only change made to the original dataset is the renaming of columns.