This dataset contains definitions for the Unified Medical Language System (UMLS) Concept Unique Identifiers (CUIs). These come from Andrew Beam's cui2vec R package.
dataset_cui2vec_definitions()Returns the cui2vec UMLS definitions as a data frame.
A data frame with 3053795 rows and 3 variables:
A Unified Medical Language System (UMLS) Concept Unique Identifier (CUI)
Semantic type of the CUI
Definition of the CUI
License
This data is made available under a MIT license. The data is copyrighted in 2019 by Benjamin Kompa, Andrew Beam, and Allen Schmaltz. The only change made to the original dataset is the renaming of columns.